const fs = require('fs');
const country = require('./district-loaded');

const defaultCode = 100000;
const data = {};

data[defaultCode] = {};

country.forEach((province) => {
  const provinces = province.districtList || province.districts;
  const provinceCode = Number(province.adcode);

  if (isNaN(provinceCode)) {
    console.log(`Invalid province code: ${provinceCode}`);
    return;
  }

  data[defaultCode][provinceCode] = province.name;

  if (Array.isArray(provinces)) {
    data[provinceCode] = {};

    provinces.forEach((city) => {
      const cities = city.districtList || city.districts;
      const cityCode = Number(city.adcode);

      if (isNaN(cityCode)) {
        console.log(`Invalid city code: ${cityCode}`);
        return;
      }

      data[provinceCode][cityCode] = city.name;

      if (Array.isArray(cities)) {
        data[cityCode] = {};

        cities.forEach((district) => {
          let districtCode = Number(district.adcode);

          if (isNaN(districtCode)) {
            console.log(`Invalid district code: ${districtCode}`);
            return;
          }

          if (district.level !== 'district') {
            console.log(`Invalid district level: ${district.level}`);
            return;
          }

          data[cityCode][districtCode] = district.name;
        });

        if (!Object.keys(data[cityCode]).length) {
          delete data[cityCode];
          console.log('Deleted empty city: ', city.name);
        }
      }
    });
  }
});

fs.writeFileSync('./district.data.js', JSON.stringify(data, false, 2));
